@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -21,28 +21,28 @@ has chord => (
 
 has position => (
     is      => 'rw',
-    isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
+    isa     => \&_positive_int,
     default => sub { 1 },
 );
 
 
 has strings => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
+    isa     => \&_positive_int,
     default => sub { 6 },
 );
 
 
 has frets => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
+    isa     => \&_positive_int,
     default => sub { 5 },
 );
 
 
 has size => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
+    isa     => \&_positive_int,
     default => sub { 30 },
 );
 
@@ -144,7 +144,7 @@ sub draw {
                 font  => $font,
                 text  => $self->position,
                 color => $BLACK,
-                x     => $SPACE / 2,
+                x     => $SPACE / 4,
                 y     => $SPACE * 2 + $SPACE / 4,
                 size  => $SPACE / 2,
                 aa    => 1,
@@ -219,6 +219,11 @@ sub draw {
         or die "Can't save $name: ", $i->errstr;
 }
 
+sub _positive_int {
+    my ($arg) = @_;
+    die "$arg is not a positive integer" unless $arg =~ /^[1-9]\d*$/;
+}
+
 1;
 
 __END__
@@ -233,7 +238,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0201
+version 0.0300
 
 =head1 SYNOPSIS
 
